@@ -1,12 +1,12 @@
-#line 1 "inc/Module/AutoInstall.pm - /usr/lib/perl5/site_perl/5.8.6/Module/AutoInstall.pm"
+#line 1 "inc/Module/AutoInstall.pm - /usr/pkg/lib/perl5/site_perl/5.8.0/Module/AutoInstall.pm"
 package Module::AutoInstall;
-$Module::AutoInstall::VERSION = '1.00';
+$Module::AutoInstall::VERSION = '1.01';
 
 use strict;
 use Cwd                 ();
 use ExtUtils::MakeMaker ();
 
-#line 222
+#line 216
 
 # special map on pre-defined feature sets
 my %FeatureMap = (
@@ -327,12 +327,8 @@ sub _install_cpanplus {
     my $cp   = CPANPLUS::Backend->new;
     my $conf = $cp->configure_object;
 
-    return
-      unless _can_write(
-          $conf->can('conf')
-        ? $conf->get_conf('base')      # 0.05x+
-        : $conf->_get_build('base')    # 0.04x
-      );
+    return unless $conf->can('conf') # 0.05x+ with "sudo" support
+               or _can_write($conf->_get_build('base'));  # 0.04x
 
     # if we're root, set UNINST=1 to avoid trouble unless user asked for it.
     my $makeflags = $conf->get_conf('makeflags') || '';
@@ -406,9 +402,11 @@ sub _install_cpan {
     CPAN::Config->load;
     require Config;
 
-    return
-      unless _can_write( MM->catfile( $CPAN::Config->{cpan_home}, 'sources' ) )
-      and _can_write( $Config::Config{sitelib} );
+    if (CPAN->VERSION < 1.80) {
+        # no "sudo" support, probe for writableness
+        return unless _can_write( MM->catfile( $CPAN::Config->{cpan_home}, 'sources' ) )
+                  and _can_write( $Config::Config{sitelib} );
+    }
 
     # if we're root, set UNINST=1 to avoid trouble unless user asked for it.
     my $makeflags = $CPAN::Config->{make_install_arg} || '';
@@ -553,7 +551,8 @@ sub _can_write {
     if (
         eval '$>' and lc(`sudo -V`) =~ /version/ and _prompt(
             qq(
-==> Should we try to re-execute the autoinstall process with 'sudo'?), 'y'
+==> Should we try to re-execute the autoinstall process with 'sudo'?),
+            ((-t STDIN) ? 'y' : 'n')
         ) =~ /^[Yy]/
       )
     {
@@ -714,4 +713,4 @@ installdeps ::
 
 __END__
 
-#line 951
+#line 943
